summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--.qmake.conf2
-rw-r--r--src/assistant/assistant/aboutdialog.cpp8
-rw-r--r--src/assistant/assistant/aboutdialog.h5
-rw-r--r--src/assistant/assistant/helpviewer.h4
-rw-r--r--src/assistant/assistant/helpviewer_qtb.cpp7
-rw-r--r--src/assistant/help/qhelpsearchresultwidget.cpp4
-rw-r--r--src/designer/src/designer/assistantclient.cpp2
-rw-r--r--src/designer/src/lib/shared/zoomwidget.cpp2
-rw-r--r--src/kmap2qmap/main.cpp14
-rw-r--r--src/linguist/linguist/mainwindow.cpp2
-rw-r--r--src/macdeployqt/macdeployqt/main.cpp4
-rw-r--r--src/macdeployqt/shared/shared.cpp11
-rw-r--r--src/makeqpf/qpf2.cpp2
-rw-r--r--src/pixeltool/qpixeltool.cpp4
-rw-r--r--src/qev/qev.cpp2
-rw-r--r--src/qtdiag/qtdiag.cpp10
-rw-r--r--src/windeployqt/main.cpp126
-rw-r--r--tests/auto/windeployqt/BLACKLIST2
18 files changed, 122 insertions, 89 deletions
diff --git a/.qmake.conf b/.qmake.conf
index 715105c47..ed2331809 100644
--- a/.qmake.conf
+++ b/.qmake.conf
@@ -2,4 +2,4 @@ load(qt_build_config)
DEFINES += QT_NO_JAVA_STYLE_ITERATORS QT_NO_LINKED_LIST
-MODULE_VERSION = 5.15.0
+MODULE_VERSION = 6.0.0
diff --git a/src/assistant/assistant/aboutdialog.cpp b/src/assistant/assistant/aboutdialog.cpp
index 3682f1291..f5a38101d 100644
--- a/src/assistant/assistant/aboutdialog.cpp
+++ b/src/assistant/assistant/aboutdialog.cpp
@@ -82,9 +82,17 @@ QVariant AboutLabel::loadResource(int type, const QUrl &name)
return QVariant();
}
+
+#if QT_VERSION < QT_VERSION_CHECK(6,0,0)
void AboutLabel::setSource(const QUrl &url)
+#else
+void AboutLabel::doSetSource(const QUrl &url, QTextDocument::ResourceType type)
+#endif
{
TRACE_OBJ
+#if QT_VERSION >= QT_VERSION_CHECK(6,0,0)
+ Q_UNUSED(type);
+#endif
if (url.isValid() && (!HelpViewer::isLocalUrl(url)
|| !HelpViewer::canOpenPage(url.path()))) {
if (!QDesktopServices::openUrl(url)) {
diff --git a/src/assistant/assistant/aboutdialog.h b/src/assistant/assistant/aboutdialog.h
index b791a4891..720292d7b 100644
--- a/src/assistant/assistant/aboutdialog.h
+++ b/src/assistant/assistant/aboutdialog.h
@@ -49,7 +49,12 @@ public:
private:
QVariant loadResource(int type, const QUrl &name) override;
+
+#if QT_VERSION < QT_VERSION_CHECK(6,0,0)
void setSource(const QUrl &url) override;
+#else
+ void doSetSource(const QUrl &name, QTextDocument::ResourceType type) override;
+#endif
QMap<QString, QByteArray> m_resourceMap;
};
diff --git a/src/assistant/assistant/helpviewer.h b/src/assistant/assistant/helpviewer.h
index 00e941000..1b4f23a9a 100644
--- a/src/assistant/assistant/helpviewer.h
+++ b/src/assistant/assistant/helpviewer.h
@@ -82,7 +82,11 @@ public:
void setTitle(const QString &title);
QUrl source() const;
+#if QT_VERSION < QT_VERSION_CHECK(6,0,0)
void setSource(const QUrl &url) TEXTBROWSER_OVERRIDE;
+#else
+ void doSetSource(const QUrl &url, QTextDocument::ResourceType type) TEXTBROWSER_OVERRIDE;
+#endif
QString selectedText() const;
bool isForwardAvailable() const;
diff --git a/src/assistant/assistant/helpviewer_qtb.cpp b/src/assistant/assistant/helpviewer_qtb.cpp
index f9bdddb52..85fe532b1 100644
--- a/src/assistant/assistant/helpviewer_qtb.cpp
+++ b/src/assistant/assistant/helpviewer_qtb.cpp
@@ -143,9 +143,16 @@ QUrl HelpViewer::source() const
return QTextBrowser::source();
}
+#if QT_VERSION < QT_VERSION_CHECK(6,0,0)
void HelpViewer::setSource(const QUrl &url)
+#else
+void HelpViewer::doSetSource(const QUrl &url, QTextDocument::ResourceType type)
+#endif
{
TRACE_OBJ
+#if QT_VERSION >= QT_VERSION_CHECK(6,0,0)
+ Q_UNUSED(type);
+#endif
if (launchWithExternalApp(url))
return;
diff --git a/src/assistant/help/qhelpsearchresultwidget.cpp b/src/assistant/help/qhelpsearchresultwidget.cpp
index b7d61b494..c439e53f7 100644
--- a/src/assistant/help/qhelpsearchresultwidget.cpp
+++ b/src/assistant/help/qhelpsearchresultwidget.cpp
@@ -113,7 +113,11 @@ signals:
void requestShowLink(const QUrl &url);
private slots:
+#if QT_VERSION < QT_VERSION_CHECK(6,0,0)
void setSource(const QUrl & /* name */) override {}
+#else
+ void doSetSource(const QUrl & /*name*/, QTextDocument::ResourceType /*type*/) override {}
+#endif
};
diff --git a/src/designer/src/designer/assistantclient.cpp b/src/designer/src/designer/assistantclient.cpp
index bf8026c3c..fb8bb5dde 100644
--- a/src/designer/src/designer/assistantclient.cpp
+++ b/src/designer/src/designer/assistantclient.cpp
@@ -85,7 +85,7 @@ bool AssistantClient::sendCommand(const QString &cmd, QString *errorMessage)
return false;
}
QTextStream str(m_process);
- str << cmd << QLatin1Char('\n') << endl;
+ str << cmd << QLatin1Char('\n') << Qt::endl;
return true;
}
diff --git a/src/designer/src/lib/shared/zoomwidget.cpp b/src/designer/src/lib/shared/zoomwidget.cpp
index fef509a39..1ca74f44b 100644
--- a/src/designer/src/lib/shared/zoomwidget.cpp
+++ b/src/designer/src/lib/shared/zoomwidget.cpp
@@ -290,7 +290,7 @@ ZoomWidget::ZoomWidget(QWidget *parent) :
void ZoomWidget::setWidget(QWidget *w, Qt::WindowFlags wFlags)
{
if (debugZoomWidget)
- qDebug() << "ZoomWidget::setWidget" << w << bin << wFlags;
+ qDebug() << "ZoomWidget::setWidget" << w << Qt::bin << wFlags;
if (m_proxy) {
scene().removeItem(m_proxy);
diff --git a/src/kmap2qmap/main.cpp b/src/kmap2qmap/main.cpp
index 0cff817c5..0f18166bd 100644
--- a/src/kmap2qmap/main.cpp
+++ b/src/kmap2qmap/main.cpp
@@ -496,27 +496,27 @@ bool KeymapParser::generateHeader(QFile *f)
{
QTextStream ts(f);
- ts << "#ifndef QEVDEVKEYBOARDHANDLER_DEFAULTMAP_H" << endl;
- ts << "#define QEVDEVKEYBOARDHANDLER_DEFAULTMAP_H" << endl << endl;
+ ts << "#ifndef QEVDEVKEYBOARDHANDLER_DEFAULTMAP_H" << Qt::endl;
+ ts << "#define QEVDEVKEYBOARDHANDLER_DEFAULTMAP_H" << Qt::endl << Qt::endl;
- ts << "const QEvdevKeyboardMap::Mapping QEvdevKeyboardHandler::s_keymap_default[] = {" << endl;
+ ts << "const QEvdevKeyboardMap::Mapping QEvdevKeyboardHandler::s_keymap_default[] = {" << Qt::endl;
for (int i = 0; i < m_keymap.size(); ++i) {
const QEvdevKeyboardMap::Mapping &m = m_keymap.at(i);
ts << QString::asprintf(" { %3d, 0x%04x, 0x%08x, 0x%02x, 0x%02x, 0x%04x },\n", m.keycode, m.unicode, m.qtcode, m.modifiers, m.flags, m.special);
}
- ts << "};" << endl << endl;
+ ts << "};" << Qt::endl << Qt::endl;
- ts << "const QEvdevKeyboardMap::Composing QEvdevKeyboardHandler::s_keycompose_default[] = {" << endl;
+ ts << "const QEvdevKeyboardMap::Composing QEvdevKeyboardHandler::s_keycompose_default[] = {" << Qt::endl;
for (int i = 0; i < m_keycompose.size(); ++i) {
const QEvdevKeyboardMap::Composing &c = m_keycompose.at(i);
ts << QString::asprintf(" { 0x%04x, 0x%04x, 0x%04x },\n", c.first, c.second, c.result);
}
- ts << "};" << endl << endl;
+ ts << "};" << Qt::endl << Qt::endl;
- ts << "#endif" << endl;
+ ts << "#endif" << Qt::endl;
return (ts.status() == QTextStream::Ok);
}
diff --git a/src/linguist/linguist/mainwindow.cpp b/src/linguist/linguist/mainwindow.cpp
index 235efd747..35ce52891 100644
--- a/src/linguist/linguist/mainwindow.cpp
+++ b/src/linguist/linguist/mainwindow.cpp
@@ -1347,7 +1347,7 @@ void MainWindow::manual()
<< (QT_VERSION >> 16) << ((QT_VERSION >> 8) & 0xFF)
<< (QT_VERSION & 0xFF)
<< QLatin1String("/qtlinguist/qtlinguist-index.html")
- << QLatin1Char('\n') << endl;
+ << QLatin1Char('\n') << Qt::endl;
}
void MainWindow::about()
diff --git a/src/macdeployqt/macdeployqt/main.cpp b/src/macdeployqt/macdeployqt/main.cpp
index 0599b739e..698176cbc 100644
--- a/src/macdeployqt/macdeployqt/main.cpp
+++ b/src/macdeployqt/macdeployqt/main.cpp
@@ -210,7 +210,9 @@ int main(int argc, char **argv)
// Update deploymentInfo.deployedFrameworks - the QML imports
// may have brought in extra frameworks as dependencies.
deploymentInfo.deployedFrameworks += findAppFrameworkNames(appBundlePath);
- deploymentInfo.deployedFrameworks = deploymentInfo.deployedFrameworks.toSet().toList();
+ deploymentInfo.deployedFrameworks =
+ QSet<QString>(deploymentInfo.deployedFrameworks.begin(),
+ deploymentInfo.deployedFrameworks.end()).values();
}
if (plugins && !deploymentInfo.qtPath.isEmpty()) {
diff --git a/src/macdeployqt/shared/shared.cpp b/src/macdeployqt/shared/shared.cpp
index 69d0ce8ca..a43267ae4 100644
--- a/src/macdeployqt/shared/shared.cpp
+++ b/src/macdeployqt/shared/shared.cpp
@@ -1462,11 +1462,12 @@ QSet<QString> codesignBundle(const QString &identity,
continue;
// Check if there are unsigned dependencies, sign these first.
- QStringList dependencies =
- getBinaryDependencies(rootBinariesPath, binary, additionalBinariesContainingRpaths).toSet()
- .subtract(signedBinaries)
- .subtract(pendingBinariesSet)
- .toList();
+ QStringList dependencies = getBinaryDependencies(rootBinariesPath, binary,
+ additionalBinariesContainingRpaths);
+ dependencies = QSet<QString>(dependencies.begin(), dependencies.end())
+ .subtract(signedBinaries)
+ .subtract(pendingBinariesSet)
+ .values();
if (!dependencies.isEmpty()) {
pendingBinaries.push(binary);
diff --git a/src/makeqpf/qpf2.cpp b/src/makeqpf/qpf2.cpp
index 41e958d82..e53aa7963 100644
--- a/src/makeqpf/qpf2.cpp
+++ b/src/makeqpf/qpf2.cpp
@@ -629,7 +629,7 @@ void QPF::dump(const QByteArray &qpf)
const QFontEngineQPF2::Block *block = reinterpret_cast<const QFontEngineQPF2::Block *>(data);
quint32 tag = qFromBigEndian(block->tag);
quint32 blockSize = qFromBigEndian(block->dataSize);
- qDebug() << "Block: Tag =" << qFromBigEndian(block->tag) << "; Size =" << blockSize << "; Offset =" << hex << data - reinterpret_cast<const uchar *>(qpf.constData());
+ qDebug() << "Block: Tag =" << qFromBigEndian(block->tag) << "; Size =" << blockSize << "; Offset =" << Qt::hex << data - reinterpret_cast<const uchar *>(qpf.constData());
data += sizeof(QFontEngineQPF2::Block);
if (debugVerbosity) {
diff --git a/src/pixeltool/qpixeltool.cpp b/src/pixeltool/qpixeltool.cpp
index 67e2afdf5..aebe13df1 100644
--- a/src/pixeltool/qpixeltool.cpp
+++ b/src/pixeltool/qpixeltool.cpp
@@ -682,8 +682,8 @@ QTextStream &operator<<(QTextStream &str, const QScreen *screen)
{
const QRect geometry = screen->geometry();
str << '"' << screen->name() << "\" " << geometry.width()
- << 'x' << geometry.height() << forcesign << geometry.x() << geometry.y()
- << noforcesign << ", " << qRound(screen->logicalDotsPerInch()) << "DPI"
+ << 'x' << geometry.height() << Qt::forcesign << geometry.x() << geometry.y()
+ << Qt::noforcesign << ", " << qRound(screen->logicalDotsPerInch()) << "DPI"
<< ", Depth: " << screen->depth() << ", " << screen->refreshRate() << "Hz";
const qreal dpr = screen->devicePixelRatio();
if (!qFuzzyCompare(dpr, qreal(1)))
diff --git a/src/qev/qev.cpp b/src/qev/qev.cpp
index b7de5dc73..01bfbd9e9 100644
--- a/src/qev/qev.cpp
+++ b/src/qev/qev.cpp
@@ -43,7 +43,7 @@ public:
bool event(QEvent *e) {
if (e->type() == QEvent::ContextMenu)
return false;
- QDebug(qout) << e << endl;
+ QDebug(qout) << e << Qt::endl;
return QWidget::event(e);
}
};
diff --git a/src/qtdiag/qtdiag.cpp b/src/qtdiag/qtdiag.cpp
index 9b082e37e..66d25bc64 100644
--- a/src/qtdiag/qtdiag.cpp
+++ b/src/qtdiag/qtdiag.cpp
@@ -102,7 +102,7 @@ QTextStream &operator<<(QTextStream &str, const QDpi &d)
QTextStream &operator<<(QTextStream &str, const QRect &r)
{
- str << r.size() << forcesign << r.x() << r.y() << noforcesign;
+ str << r.size() << Qt::forcesign << r.x() << r.y() << Qt::noforcesign;
return str;
}
@@ -247,9 +247,9 @@ void dumpVkInfo(QTextStream &str)
window.setVulkanInstance(&inst);
for (const VkPhysicalDeviceProperties &props : window.availablePhysicalDevices()) {
str << " API version " << vulkanVersion(props.apiVersion).toString()
- << hex << ", vendor 0x" << props.vendorID
+ << Qt::hex << ", vendor 0x" << props.vendorID
<< ", device 0x" << props.deviceID << ", " << props.deviceName
- << dec << ", type " << props.deviceType
+ << Qt::dec << ", type " << props.deviceType
<< ", driver version " << vulkanVersion(props.driverVersion).toString();
}
} else {
@@ -480,7 +480,7 @@ QString qtDiag(unsigned flags)
# ifndef QT_NO_SSL
if (QSslSocket::supportsSsl()) {
str << "Using \"" << QSslSocket::sslLibraryVersionString() << "\", version: 0x"
- << hex << QSslSocket::sslLibraryVersionNumber() << dec;
+ << Qt::hex << QSslSocket::sslLibraryVersionNumber() << Qt::dec;
} else {
str << "\nSSL is not supported.";
}
@@ -528,7 +528,7 @@ QString qtDiag(unsigned flags)
if (passwordMaskCharacter.unicode() >= 32 && passwordMaskCharacter.unicode() < 128)
str << '\'' << passwordMaskCharacter << '\'';
else
- str << "U+" << qSetFieldWidth(4) << qSetPadChar('0') << uppercasedigits << hex << passwordMaskCharacter.unicode() << dec << qSetFieldWidth(0);
+ str << "U+" << qSetFieldWidth(4) << qSetPadChar('0') << Qt::uppercasedigits << Qt::hex << passwordMaskCharacter.unicode() << Qt::dec << qSetFieldWidth(0);
str << '\n'
<< " fontSmoothingGamma: " << styleHints->fontSmoothingGamma() << '\n'
<< " useRtlExtensions: " << styleHints->useRtlExtensions() << '\n'
diff --git a/tests/auto/windeployqt/BLACKLIST b/tests/auto/windeployqt/BLACKLIST
new file mode 100644
index 000000000..372edcb9d
--- /dev/null
+++ b/tests/auto/windeployqt/BLACKLIST
@@ -0,0 +1,2 @@
+[deploy]
+windows
diff --git a/src/windeployqt/main.cpp b/src/windeployqt/main.cpp
index a4cededce..38869b282 100644
--- a/src/windeployqt/main.cpp
+++ b/src/windeployqt/main.cpp
@@ -120,58 +120,58 @@ struct QtModuleEntry {
};
static QtModuleEntry qtModuleEntries[] = {
- { QtBluetoothModule, "bluetooth", "Qt5Bluetooth", nullptr },
- { QtConcurrentModule, "concurrent", "Qt5Concurrent", "qtbase" },
- { QtCoreModule, "core", "Qt5Core", "qtbase" },
- { QtDeclarativeModule, "declarative", "Qt5Declarative", "qtquick1" },
- { QtDesignerModule, "designer", "Qt5Designer", nullptr },
- { QtDesignerComponents, "designercomponents", "Qt5DesignerComponents", nullptr },
+ { QtBluetoothModule, "bluetooth", "Qt6Bluetooth", nullptr },
+ { QtConcurrentModule, "concurrent", "Qt6Concurrent", "qtbase" },
+ { QtCoreModule, "core", "Qt6Core", "qtbase" },
+ { QtDeclarativeModule, "declarative", "Qt6Declarative", "qtquick1" },
+ { QtDesignerModule, "designer", "Qt6Designer", nullptr },
+ { QtDesignerComponents, "designercomponents", "Qt6DesignerComponents", nullptr },
{ QtEnginioModule, "enginio", "Enginio", nullptr },
- { QtGamePadModule, "gamepad", "Qt5Gamepad", nullptr },
- { QtGuiModule, "gui", "Qt5Gui", "qtbase" },
- { QtHelpModule, "qthelp", "Qt5Help", "qt_help" },
- { QtMultimediaModule, "multimedia", "Qt5Multimedia", "qtmultimedia" },
- { QtMultimediaWidgetsModule, "multimediawidgets", "Qt5MultimediaWidgets", "qtmultimedia" },
- { QtMultimediaQuickModule, "multimediaquick", "Qt5MultimediaQuick_p", "qtmultimedia" },
- { QtNetworkModule, "network", "Qt5Network", "qtbase" },
- { QtNfcModule, "nfc", "Qt5Nfc", nullptr },
- { QtOpenGLModule, "opengl", "Qt5OpenGL", nullptr },
- { QtPositioningModule, "positioning", "Qt5Positioning", nullptr },
- { QtPrintSupportModule, "printsupport", "Qt5PrintSupport", nullptr },
- { QtQmlModule, "qml", "Qt5Qml", "qtdeclarative" },
+ { QtGamePadModule, "gamepad", "Qt6Gamepad", nullptr },
+ { QtGuiModule, "gui", "Qt6Gui", "qtbase" },
+ { QtHelpModule, "qthelp", "Qt6Help", "qt_help" },
+ { QtMultimediaModule, "multimedia", "Qt6Multimedia", "qtmultimedia" },
+ { QtMultimediaWidgetsModule, "multimediawidgets", "Qt6MultimediaWidgets", "qtmultimedia" },
+ { QtMultimediaQuickModule, "multimediaquick", "Qt6MultimediaQuick_p", "qtmultimedia" },
+ { QtNetworkModule, "network", "Qt6Network", "qtbase" },
+ { QtNfcModule, "nfc", "Qt6Nfc", nullptr },
+ { QtOpenGLModule, "opengl", "Qt6OpenGL", nullptr },
+ { QtPositioningModule, "positioning", "Qt6Positioning", nullptr },
+ { QtPrintSupportModule, "printsupport", "Qt6PrintSupport", nullptr },
+ { QtQmlModule, "qml", "Qt6Qml", "qtdeclarative" },
{ QtQmlToolingModule, "qmltooling", "qmltooling", nullptr },
- { QtQuickModule, "quick", "Qt5Quick", "qtdeclarative" },
- { QtQuickParticlesModule, "quickparticles", "Qt5QuickParticles", nullptr },
- { QtQuickWidgetsModule, "quickwidgets", "Qt5QuickWidgets", nullptr },
- { QtScriptModule, "script", "Qt5Script", "qtscript" },
- { QtScriptToolsModule, "scripttools", "Qt5ScriptTools", "qtscript" },
- { QtSensorsModule, "sensors", "Qt5Sensors", nullptr },
- { QtSerialPortModule, "serialport", "Qt5SerialPort", "qtserialport" },
- { QtSqlModule, "sql", "Qt5Sql", "qtbase" },
- { QtSvgModule, "svg", "Qt5Svg", nullptr },
- { QtTestModule, "test", "Qt5Test", "qtbase" },
- { QtWebKitModule, "webkit", "Qt5WebKit", nullptr },
- { QtWebKitWidgetsModule, "webkitwidgets", "Qt5WebKitWidgets", nullptr },
- { QtWebSocketsModule, "websockets", "Qt5WebSockets", nullptr },
- { QtWidgetsModule, "widgets", "Qt5Widgets", "qtbase" },
- { QtWinExtrasModule, "winextras", "Qt5WinExtras", nullptr },
- { QtXmlModule, "xml", "Qt5Xml", "qtbase" },
- { QtXmlPatternsModule, "xmlpatterns", "Qt5XmlPatterns", "qtxmlpatterns" },
- { QtWebEngineCoreModule, "webenginecore", "Qt5WebEngineCore", nullptr },
- { QtWebEngineModule, "webengine", "Qt5WebEngine", "qtwebengine" },
- { QtWebEngineWidgetsModule, "webenginewidgets", "Qt5WebEngineWidgets", nullptr },
- { Qt3DCoreModule, "3dcore", "Qt53DCore", nullptr },
- { Qt3DRendererModule, "3drenderer", "Qt53DRender", nullptr },
- { Qt3DQuickModule, "3dquick", "Qt53DQuick", nullptr },
- { Qt3DQuickRendererModule, "3dquickrenderer", "Qt53DQuickRender", nullptr },
- { Qt3DInputModule, "3dinput", "Qt53DInput", nullptr },
- { Qt3DAnimationModule, "3danimation", "Qt53DAnimation", nullptr },
- { Qt3DExtrasModule, "3dextras", "Qt53DExtras", nullptr },
- { QtLocationModule, "geoservices", "Qt5Location", nullptr },
- { QtWebChannelModule, "webchannel", "Qt5WebChannel", nullptr },
- { QtTextToSpeechModule, "texttospeech", "Qt5TextToSpeech", nullptr },
- { QtSerialBusModule, "serialbus", "Qt5SerialBus", nullptr },
- { QtWebViewModule, "webview", "Qt5WebView", nullptr }
+ { QtQuickModule, "quick", "Qt6Quick", "qtdeclarative" },
+ { QtQuickParticlesModule, "quickparticles", "Qt6QuickParticles", nullptr },
+ { QtQuickWidgetsModule, "quickwidgets", "Qt6QuickWidgets", nullptr },
+ { QtScriptModule, "script", "Qt6Script", "qtscript" },
+ { QtScriptToolsModule, "scripttools", "Qt6ScriptTools", "qtscript" },
+ { QtSensorsModule, "sensors", "Qt6Sensors", nullptr },
+ { QtSerialPortModule, "serialport", "Qt6SerialPort", "qtserialport" },
+ { QtSqlModule, "sql", "Qt6Sql", "qtbase" },
+ { QtSvgModule, "svg", "Qt6Svg", nullptr },
+ { QtTestModule, "test", "Qt6Test", "qtbase" },
+ { QtWebKitModule, "webkit", "Qt6WebKit", nullptr },
+ { QtWebKitWidgetsModule, "webkitwidgets", "Qt6WebKitWidgets", nullptr },
+ { QtWebSocketsModule, "websockets", "Qt6WebSockets", nullptr },
+ { QtWidgetsModule, "widgets", "Qt6Widgets", "qtbase" },
+ { QtWinExtrasModule, "winextras", "Qt6WinExtras", nullptr },
+ { QtXmlModule, "xml", "Qt6Xml", "qtbase" },
+ { QtXmlPatternsModule, "xmlpatterns", "Qt6XmlPatterns", "qtxmlpatterns" },
+ { QtWebEngineCoreModule, "webenginecore", "Qt6WebEngineCore", nullptr },
+ { QtWebEngineModule, "webengine", "Qt6WebEngine", "qtwebengine" },
+ { QtWebEngineWidgetsModule, "webenginewidgets", "Qt6WebEngineWidgets", nullptr },
+ { Qt3DCoreModule, "3dcore", "Qt63DCore", nullptr },
+ { Qt3DRendererModule, "3drenderer", "Qt63DRender", nullptr },
+ { Qt3DQuickModule, "3dquick", "Qt63DQuick", nullptr },
+ { Qt3DQuickRendererModule, "3dquickrenderer", "Qt63DQuickRender", nullptr },
+ { Qt3DInputModule, "3dinput", "Qt63DInput", nullptr },
+ { Qt3DAnimationModule, "3danimation", "Qt63DAnimation", nullptr },
+ { Qt3DExtrasModule, "3dextras", "Qt63DExtras", nullptr },
+ { QtLocationModule, "geoservices", "Qt6Location", nullptr },
+ { QtWebChannelModule, "webchannel", "Qt6WebChannel", nullptr },
+ { QtTextToSpeechModule, "texttospeech", "Qt6TextToSpeech", nullptr },
+ { QtSerialBusModule, "serialbus", "Qt6SerialBus", nullptr },
+ { QtWebViewModule, "webview", "Qt6WebView", nullptr }
};
enum QtPlugin {
@@ -372,7 +372,7 @@ static inline int parseArguments(const QStringList &arguments, QCommandLineParse
parser->addOption(dryRunOption);
QCommandLineOption noPatchQtOption(QStringLiteral("no-patchqt"),
- QStringLiteral("Do not patch the Qt5Core library."));
+ QStringLiteral("Do not patch the Qt6Core library."));
parser->addOption(noPatchQtOption);
QCommandLineOption noPluginsOption(QStringLiteral("no-plugins"),
@@ -696,7 +696,7 @@ static inline QString helpText(const QCommandLineParser &p)
static inline bool isQtModule(const QString &libName)
{
// Match Standard modules named Qt5XX.dll
if (libName.size() < 3 || !libName.startsWith(QLatin1String("Qt"), Qt::CaseInsensitive))
return false;
const QChar version = libName.at(2);
@@ -867,7 +867,7 @@ static inline quint64 qtModuleForPlugin(const QString &subDirName)
static quint64 qtModule(QString module, const QString &infix)
{
// Match needle 'path/Qt5Core<infix><d>.dll' or 'path/libQt5Core<infix>.so.5.0'
const int lastSlashPos = module.lastIndexOf(QLatin1Char('/'));
if (lastSlashPos > 0)
module.remove(0, lastSlashPos + 1);
@@ -878,7 +878,7 @@ static quint64 qtModule(QString module, const QString &infix)
endPos = module.indexOf(QLatin1Char('.')); // strip suffixes '.so.5.0'.
if (endPos > 0)
module.truncate(endPos);
// That should leave us with 'Qt5Core<d>'.
for (const auto &qtModule : qtModuleEntries) {
const QLatin1String libraryName(qtModule.libraryName);
if (module == libraryName
@@ -1193,7 +1193,7 @@ static inline int qtVersion(const QMap<QString, QString> &qmakeVariables)
return (majorVersion << 16) | (minorVersion << 8) | patchVersion;
}
// Determine the Qt lib infix from the library path of "Qt5Core<qtblibinfix>[d].dll".
static inline QString qtlibInfixFromCoreLibName(const QString &path, bool isDebug, Platform platform)
{
const int startPos = path.lastIndexOf(QLatin1Char('/')) + 8;
@@ -1283,11 +1283,11 @@ static DeployResult deploy(const Options &options,
return result;
}
// Some Windows-specific checks: Qt5Core depends on ICU when configured with "-icu". Other than
// that, Qt5WebKit has a hard dependency on ICU.
if (options.platform & WindowsBased) {
- const QStringList qtLibs = dependentQtLibs.filter(QStringLiteral("Qt5Core"), Qt::CaseInsensitive)
- + dependentQtLibs.filter(QStringLiteral("Qt5WebKit"), Qt::CaseInsensitive);
+ const QStringList qtLibs = dependentQtLibs.filter(QStringLiteral("Qt6Core"), Qt::CaseInsensitive)
+ + dependentQtLibs.filter(QStringLiteral("Qt6WebKit"), Qt::CaseInsensitive);
for (const QString &qtLib : qtLibs) {
QStringList icuLibs = findDependentLibraries(qtLib, options.platform, errorMessage).filter(QStringLiteral("ICU"), Qt::CaseInsensitive);
if (!icuLibs.isEmpty()) {
@@ -1312,7 +1312,7 @@ static DeployResult deploy(const Options &options,
} // for each icuLib
break;
} // !icuLibs.isEmpty()
- } // Qt5Core/Qt5WebKit
+ } // Qt6Core/Qt6WebKit
} // Windows
// Scan Quick2 imports
@@ -1404,7 +1404,7 @@ static DeployResult deploy(const Options &options,
return result;
}
// Check for ANGLE on the Qt5Gui library.
if ((options.platform & WindowsBased) && options.platform != WinCEIntel
&& options.platform != WinCEArm && !qtGuiLibrary.isEmpty()) {
QString libGlesName = QStringLiteral("libGLESV2");
@@ -1491,10 +1491,10 @@ static DeployResult deploy(const Options &options,
}
if (options.patchQt && !options.dryRun && !options.isWinRt()) {
- const QString qt5CoreName = QFileInfo(libraryPath(libraryLocation, "Qt5Core", qtLibInfix,
+ const QString qt6CoreName = QFileInfo(libraryPath(libraryLocation, "Qt6Core", qtLibInfix,
options.platform, isDebug)).fileName();
- if (!patchQtCore(targetPath + QLatin1Char('/') + qt5CoreName, errorMessage)) {
+ if (!patchQtCore(targetPath + QLatin1Char('/') + qt6CoreName, errorMessage)) {
std::wcerr << "Warning: " << *errorMessage << '\n';
errorMessage->clear();
}
@@ -696,7 +696,7 @@ static inline QString helpText(const QCommandLineParser &p)
static inline bool isQtModule(const QString &libName)
{
- // Match Standard modules named Qt5XX.dll
+ // Match Standard modules named Qt6XX.dll
if (libName.size() < 3 || !libName.startsWith(QLatin1String("Qt"), Qt::CaseInsensitive))
return false;
@@ -867,7 +867,7 @@ static inline quint64 qtModuleForPlugin(const QString &subDirName)
static quint64 qtModule(QString module, const QString &infix)
{
- // Match needle 'path/Qt5Core<infix><d>.dll' or 'path/libQt5Core<infix>.so.5.0'
+ // Match needle 'path/Qt6Core<infix><d>.dll' or 'path/libQt6Core<infix>.so.5.0'
const int lastSlashPos = module.lastIndexOf(QLatin1Char('/'));
if (lastSlashPos > 0)
@@ -878,7 +878,7 @@ static quint64 qtModule(QString module, const QString &infix)
if (endPos > 0)
module.truncate(endPos);
- // That should leave us with 'Qt5Core<d>'.
+ // That should leave us with 'Qt6Core<d>'.
for (const auto &qtModule : qtModuleEntries) {
const QLatin1String libraryName(qtModule.libraryName);
@@ -1193,7 +1193,7 @@ static inline int qtVersion(const QMap<QString, QString> &qmakeVariables)
return (majorVersion << 16) | (minorVersion << 8) | patchVersion;
}
-// Determine the Qt lib infix from the library path of "Qt5Core<qtblibinfix>[d].dll".
+// Determine the Qt lib infix from the library path of "Qt6Core<qtblibinfix>[d].dll".
static inline QString qtlibInfixFromCoreLibName(const QString &path, bool isDebug, Platform platform)
{
@@ -1283,11 +1283,11 @@ static DeployResult deploy(const Options &options,
return result;
}
- // Some Windows-specific checks: Qt5Core depends on ICU when configured with "-icu". Other than
- // that, Qt5WebKit has a hard dependency on ICU.
+ // Some Windows-specific checks: Qt6Core depends on ICU when configured with "-icu". Other than
+ // that, Qt6WebKit has a hard dependency on ICU.
if (options.platform & WindowsBased) {
@@ -1404,7 +1404,7 @@ static DeployResult deploy(const Options &options,
return result;
}
- // Check for ANGLE on the Qt5Gui library.
+ // Check for ANGLE on the Qt6Gui library.
if ((options.platform & WindowsBased) && options.platform != WinCEIntel
&& options.platform != WinCEArm && !qtGuiLibrary.isEmpty()) {